pub(crate) fn build_or_load_graph(
opts: BuildOptions<'_>,
) -> Result<(CodePropertyGraph, usize)>Expand description
Build a graph from source or load from cache.
pub(crate) fn build_or_load_graph(
opts: BuildOptions<'_>,
) -> Result<(CodePropertyGraph, usize)>Build a graph from source or load from cache.